@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 from django.contrib import admin
 from coop.org.models import BaseEngagement, BaseRelation
+from coop.person.models import BasePerson
 from coop.exchange.models import BaseExchange, BasePaymentModality, BaseTransaction, BaseProduct
 from django.db import models
 from django import forms
@@ -55,7 +56,7 @@ class M2MLinkWidget(forms.Widget):
         super(M2MLinkWidget, self).__init__(attrs)
 
     def render(self, name, value, attrs=None):
-        if self.object.pk:
+        if self.object.pk and self.fkey and getattr(self.object, self.fkey) != None:
             return mark_safe(u'<a href="../../../%s/%s/%s/">%s</a>' % \
                 (self.object._meta.app_label,
                     getattr(self.object, self.fkey)._meta.object_name.lower(), 
@@ -96,6 +97,7 @@ class OrgInlineLinkForm(forms.ModelForm):
 # ---------- if coop-geo is installed --------------
 
 if "coop_geo" in settings.INSTALLED_APPS:
+    from coop_geo.forms import AreaFormForInline
     from coop_geo.models import AreaLink, Located
 
     class LocatedInlineLinkForm(forms.ModelForm):
@@ -111,11 +113,23 @@ if "coop_geo" in settings.INSTALLED_APPS:
         related_search_fields = {'location': ('label', 'adr1', 'adr2', 'zipcode', 'city'), }
         extra = 1
 
-    class AreaInline(GenericTabularInline, InlineAutocompleteAdmin):
-        model = AreaLink
+    class AreaInline(GenericTabularInline):
+        form = AreaFormForInline
         related_search_fields = {'location': ('label', 'reference'), }
+        model = AreaLink
         extra = 1
 
+        def formfield_for_foreignkey(self, db_field, request=None, **kwargs):
+            associated_obj = None
+            if db_field.name == "location":
+                if request._obj_ is not None:
+                    associated_obj = request._obj_
+            r = super(AreaInline, self).formfield_for_foreignkey(db_field,
+                                                          request, **kwargs)
+            # decorate the modelform in order to use it in the area widget
+            r._associated_obj = request._obj_
+            return r
+
 # ----------------------------------------------------
 
 
@@ -124,7 +138,7 @@ class URLFieldWidget(AdminURLFieldWidget):
         widget = super(URLFieldWidget, self).render(name, value, attrs)
         return mark_safe(u'%s&nbsp;&nbsp;<a href="#" onclick="window.'
                          u'open(document.getElementById(\'%s\')'
-                         u'.value);return false;" /></a>' % (widget, attrs['id']))
+                         u'.value);return false;" />Afficher</a>' % (widget, attrs['id']))
 
 
 class BaseEngagementInline(InlineAutocompleteAdmin):
@@ -212,15 +226,6 @@ class BaseOrganizationAdminForm(forms.ModelForm):
             )
 
 
-class BaseMemberAdminForm(forms.ModelForm):
-    # category = chosenforms.ChosenModelMultipleChoiceField(
-    #         required=False,
-    #         overlay=_(u"Choose one or more categories"),
-    #         queryset=get_model('coop_local','PersonCategory').objects.all())    
-    class Meta:
-        widgets = {'category': chosenwidgets.ChosenSelectMultiple()}
-
-
 class BaseExchangeAdmin(ForeignKeyAutocompleteAdmin):  # AdminImageMixin, 
     fieldsets = ((None, {
             'fields': (('etype', 'permanent', 'expiration', ), 'title', 'description',
@@ -283,6 +288,11 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
         return dict(myactions, **super(BaseOrganizationAdmin, self).get_actions(request))  # merging two dicts
         #list_display = ['my_image_thumb', 'my_other_field1', 'my_other_field2', ] ???
 
+    def get_form(self, request, obj=None, **kwargs):
+        # just save obj reference for future processing in Inline
+        request._obj_ = obj
+        return super(BaseOrganizationAdmin, self).get_form(request, obj, **kwargs)
+
     def logo_thumb(self, obj):
         if obj.logo:
             thumb = default.backend.get_thumbnail(obj.logo.file, ADMIN_THUMBS_SIZE)
@@ -294,34 +304,44 @@ class BaseOrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
 
     class Media:
         js = ('/static/js/admin_customize.js',)
+ 
+
+class BasePersonAdminForm(forms.ModelForm):
+    # model = BasePerson
+    # category = chosenforms.ChosenModelMultipleChoiceField(
+    #         required=False,
+    #         overlay=_(u"Choose one or more categories"),
+    #         queryset=get_model('coop_local', 'PersonCategory').objects.all())    
+    class Meta:
+        widgets = {'category': chosenwidgets.ChosenSelectMultiple()}
 
 
-from django_extensions.admin import ForeignKeyAutocompleteAdmin
-        
-
-class BasePersonAdmin(ForeignKeyAutocompleteAdmin):
-    # model is not given because the coop_local "true" model will override this
-    form = BaseMemberAdminForm
-    list_display = ('last_name','first_name','email','structure','has_user_account','has_role')
+class BasePersonAdmin(ForeignKeyAutocompleteAdmin):  # FkAutocompleteAdmin too but...
+    form = BasePersonAdminForm
+    list_display = ('last_name', 'first_name', 'email', 'structure', 'has_user_account', 'has_role')
     list_filter = ('category',)
-    list_display_links =('last_name','first_name')
-    search_fields = ('last_name','first_name','email','structure')    
+    list_display_links = ('last_name', 'first_name')
+    search_fields = ('last_name', 'first_name', 'email', 'structure')    
     ordering = ('last_name',)
-    #inlines = [BaseEngInitInline,]
+    # inlines = [ContactInline,
+    #             OrgInline,
+    #             SeeAlsoInline,
+    #             ]
+
     def get_actions(self, request):
-        myactions = dict(create_action(s) for s in get_model('coop_local','PersonCategory').objects.all())
-        return dict(myactions, **super(BasePersonAdmin, self).get_actions(request))#merging two dicts
+        myactions = dict(create_action(s) for s in get_model('coop_local', 'PersonCategory').objects.all())
+        return dict(myactions, **super(BasePersonAdmin, self).get_actions(request))  # merging two dicts
     
     fieldsets = (
         (None, {
-            'fields' : (('first_name','last_name'),
+            'fields': (('first_name', 'last_name'),
                         'email',
                         'category'
                         ),
             }),
         ('Notes', {
             'classes': ('collapse',),
-            'fields': ('structure','notes',)
+            'fields': ('structure', 'notes',)
         })
     )
 
@@ -331,11 +351,10 @@ from django.contrib.admin.util import get_model_from_relation
 from django.db.models import Count
 
 
-if "coop_tag" in settings.INSTALLED_APPS :
+if "coop_tag" in settings.INSTALLED_APPS:
 
     #from taggit.managers import TaggableManager
     from taggit_autosuggest.managers import TaggableManager
-    from coop_tag.models import Ctag
 
     class TaggitFilterSpec(RelatedFilterSpec):
         """
@@ -357,7 +376,7 @@ if "coop_tag" in settings.INSTALLED_APPS :
                 # no direct field on this model, get name from other model
                 self.lookup_title = other_model._meta.verbose_name
             else:
-                self.lookup_title = f.verbose_name # use field name
+                self.lookup_title = f.verbose_name  # use field name
             rel_name = other_model._meta.pk.name
             self.lookup_kwarg = '%s__%s__exact' % (self.field_path, rel_name)
             self.lookup_kwarg_isnull = '%s__isnull' % (self.field_path)
@@ -380,7 +399,3 @@ if "coop_tag" in settings.INSTALLED_APPS :
     # to be picked as a RelatedFilterSpec
     FilterSpec.filter_specs.insert(0, (lambda f: isinstance(f, TaggableManager),
         TaggitFilterSpec))
-    
-    
-
-
